# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.1.1 2024-10-11

### Removed

    `redundent.prod()`. It was annoying type checkers and is, after all, redundent.

### Added

- `utils.xor()` function for xor-ing bytes with a pad.
- Explicit support for Python 3.13
- Github Actions for linting and testing

### Improved

    - Conforms to some stronger lint checks
    - Spelling in some code comments

## 0.1.0 - 2024-10-10

### Added

    - First public release
  